Innate stands for Integrated Neural Network Automatic Trainer and Evaluator. It is a framework for training neural networks and optimizing their hyperparameters. The base concept is to provide, at the user level, a complete abstraction of the training of a neural network on a cluster. The user can use the interface to launch tasks and get results as if they were executed on its own machine. The runtime provided by the framework simplify also the necessary code for training.

This package is the interface library to connect to an innate server and execute training.
